import { createElement } from 'react';

// src/HTML2React/index.ts
var NON_WHITESPACE_CHARACTER = /\S/;
var HTML_SPECIAL_CHAR = /[\s>/]/;
var HTML_ATTRIBUTE_CHAR = /[=\s>/]/;
var VOID_TAGS = /* @__PURE__ */ new Set([
  "area",
  "base",
  "br",
  "col",
  "embed",
  "hr",
  "img",
  "input",
  "link",
  "meta",
  "param",
  "source",
  "track",
  "wbr"
]);
var _isVoidTag = VOID_TAGS.has.bind(VOID_TAGS);
var _handleIndex = (index) => {
  if (index < 0) {
    throw new Error("invalid html");
  }
  return index;
};
var HTML2React = ({
  html,
  components = {},
  attributes = {},
  converters = {},
  processTextSegment
}) => {
  let start = 0;
  const tagsQueue = new Array(1);
  const root = [];
  const childrenQueue = [root];
  const substring = html.substring.bind(html);
  const _indexOf = html.indexOf.bind(html);
  const search = (index, regexp) => index + _handleIndex(substring(index).search(regexp));
  const indexOf = (item, index) => _handleIndex(_indexOf(item, index));
  const handleTextSegment = processTextSegment ? (nodes, start2, end) => {
    let l = nodes.length;
    const segment = processTextSegment(substring(start2, end), () => l++);
    if (Array.isArray(segment)) {
      nodes.push(...segment);
    } else {
      nodes.push(segment);
    }
  } : (nodes, start2, end) => {
    nodes.push(substring(start2, end));
  };
  for (let index = _indexOf("<"), char, end, _next, tag, attribute, value, props, parentChildren = root; index != -1; parentChildren = childrenQueue[childrenQueue.length - 1]) {
    end = _indexOf(">", index + 1);
    if (end > 0) {
      while (true) {
        _next = _indexOf("<", index + 1);
        if (_next > 0 && _next < end) {
          index = _next;
        } else {
          break;
        }
      }
    } else {
      break;
    }
    if (start != index) {
      handleTextSegment(parentChildren, start, index);
    }
    char = html[++index];
    if (char == "/") {
      tag = substring(index + 1, end).trim();
      for (let j = tagsQueue.length; j--; ) {
        if (tagsQueue[j] == tag) {
          tagsQueue.length = j;
          childrenQueue.length = j;
          break;
        }
      }
    } else if (char != "!") {
      tag = substring(
        index,
        index = search(index + 1, HTML_SPECIAL_CHAR)
      ).trim();
      index = search(index, NON_WHITESPACE_CHARACTER);
      props = {
        key: parentChildren.length
      };
      while (end != index && html[index] != "/") {
        attribute = substring(
          index,
          index = search(index + 1, HTML_ATTRIBUTE_CHAR)
        ).trim();
        if (attribute in attributes) {
          attribute = attributes[attribute];
        }
        char = html[index];
        if (char != "=" && char != "/" && char != ">") {
          index = search(index + 1, NON_WHITESPACE_CHARACTER);
        }
        if (html[index] == "=") {
          char = html[index = search(index + 1, NON_WHITESPACE_CHARACTER)];
          const isWrapped = char == "'" || char == '"';
          const next = isWrapped ? indexOf(char, ++index) : search(index + 1, HTML_SPECIAL_CHAR);
          value = substring(index, next);
          index = search(next + isWrapped, NON_WHITESPACE_CHARACTER);
        } else {
          value = "true";
        }
        props[attribute] = attribute in converters ? converters[attribute](value, tag) : value;
      }
      if (tag != "script") {
        if (!_isVoidTag(tag)) {
          childrenQueue.push(props.children = []);
          tagsQueue.push(tag);
        }
      } else {
        const str = substring(end + 1);
        const scriptClosingTag = /<\/\s*script\s*>/.exec(str);
        if (scriptClosingTag) {
          const indexOfNextScriptOpenTag = str.search(/<\s*script\s*>/);
          const indexOfScriptClosingTag = scriptClosingTag.index;
          if (indexOfNextScriptOpenTag == -1 || indexOfScriptClosingTag < indexOfNextScriptOpenTag) {
            const code = str.substring(0, indexOfScriptClosingTag);
            if (code) {
              props.dangerouslySetInnerHTML = { __html: code };
            }
            end += indexOfScriptClosingTag + scriptClosingTag[0].length;
          }
        }
      }
      parentChildren.push(
        createElement(tag in components ? components[tag] : tag, props)
      );
    } else if (html[++index] == "-" && html[++index] == "-") {
      end = indexOf("-->", index) + 2;
    }
    start = end + 1;
    index = _next;
  }
  if (start < html.length) {
    handleTextSegment(childrenQueue[childrenQueue.length - 1], start);
  }
  return root.length > 1 ? root : root[0];
};
var HTML2React_default = HTML2React;

export { HTML2React_default };
//# sourceMappingURL=out.js.map
//# sourceMappingURL=chunk-4NPWPFBI.js.map